==> haskell-should-not-typecheck-2.1.0-267-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 should-not-typecheck
version:              2.1.0
visibility:           public
id:                   should-not-typecheck-2.1.0-DXJJN84dPMw4TPftPrYwM3
key:                  should-not-typecheck-2.1.0-DXJJN84dPMw4TPftPrYwM3
license:              BSD-3-Clause
maintainer:           message.me.on@github.com
author:               Callum Rogers
homepage:             http://github.com/CRogers/should-not-typecheck
synopsis:
    A HUnit/hspec assertion library to verify that an expression does not typecheck

description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.

category:             Testing
abi:                  7f4f56c68f342f003579c1f2ec58c1db
exposed:              True
exposed-modules:      Test.ShouldNotTypecheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/should-not-typecheck-2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-should-not-typecheck
hs-libraries:         HSshould-not-typecheck-2.1.0-DXJJN84dPMw4TPftPrYwM3
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy base-4.16.4.0 deepseq-1.4.6.1

haddock-interfaces:
    /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock

haddock-html:         /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-should-not-typecheck-2.1.0-268-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 should-not-typecheck
version:              2.1.0
visibility:           public
id:                   should-not-typecheck-2.1.0-aEJsX61Lk9HH8pkomAGol
key:                  should-not-typecheck-2.1.0-aEJsX61Lk9HH8pkomAGol
license:              BSD-3-Clause
maintainer:           message.me.on@github.com
author:               Callum Rogers
homepage:             http://github.com/CRogers/should-not-typecheck
synopsis:
    A HUnit/hspec assertion library to verify that an expression does not typecheck

description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.

category:             Testing
abi:                  8e68dbc3406b2b09ce7ce8b5875c7886
exposed:              True
exposed-modules:      Test.ShouldNotTypecheck
import-dirs:          /usr/lib/ghc-9.2.8/site-local/should-not-typecheck-2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-should-not-typecheck
hs-libraries:         HSshould-not-typecheck-2.1.0-aEJsX61Lk9HH8pkomAGol
depends:
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY base-4.16.4.0 deepseq-1.4.6.1

haddock-interfaces:
    /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock

haddock-html:         /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
